==> easy-props-2.0.1-sources.jar: org/jeasy/props/PropertiesInjectionTask.java <==
/**
 * The MIT License
 *
 *   Copyright (c) 2017, Mahmoud Ben Hassine (mahmoud.benhassine@icloud.com)
 *
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *
 *   The above copyright notice and this permission notice shall be included in
 *   all copies or substantial portions of the Software.
 *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *   THE SOFTWARE.
 */
package org.jeasy.props;

import org.jeasy.props.api.PropertiesInjector;
import org.jeasy.props.api.PropertyInjectionException;

import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Background task for configuration hot reloading.
 *
 * @author Mahmoud Ben Hassine (mahmoud.benhassine@icloud.com)
 */
class PropertiesInjectionTask implements Runnable {

    private static Logger LOGGER = Logger.getLogger(PropertiesInjectionTask.class.getName());

    private PropertiesInjector injector;

    private Object target;

    PropertiesInjectionTask(PropertiesInjector injector, Object target) {
        this.injector = injector;
        this.target = target;
    }

    @Override
    public void run() {
        try {
            injector.injectProperties(target);
        } catch (PropertyInjectionException e) {
            LOGGER.log(Level.SEVERE, "Unable to inject properties in object: " + target, e);
        }
    }
}

==> easy-props-3.1.0-sources.jar: org/jeasy/props/PropertiesInjectionTask.java <==
/*
 * The MIT License
 *
 *   Copyright (c) 2020, Mahmoud Ben Hassine (mahmoud.benhassine@icloud.com)
 *
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *
 *   The above copyright notice and this permission notice shall be included in
 *   all copies or substantial portions of the Software.
 *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *   THE SOFTWARE.
 */
package org.jeasy.props;

import org.jeasy.props.api.PropertiesInjector;
import org.jeasy.props.api.PropertyInjectionException;

import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Background task for configuration hot reloading.
 *
 * @author Mahmoud Ben Hassine (mahmoud.benhassine@icloud.com)
 */
class PropertiesInjectionTask implements Runnable {

    private static final Logger LOGGER = Logger.getLogger(PropertiesInjectionTask.class.getName());

    private final PropertiesInjector injector;

    private final Object target;

    PropertiesInjectionTask(PropertiesInjector injector, Object target) {
        this.injector = injector;
        this.target = target;
    }

    @Override
    public void run() {
        try {
            injector.injectProperties(target);
        } catch (PropertyInjectionException e) {
            LOGGER.log(Level.SEVERE, "Unable to inject properties in object '" + target + "'", e);
        }
    }
}
